@@ -67,7 +67,7 @@ class CodeHandler(unittest.TestCase):
         self.env = {'PYTHONPATH': os.getcwd()}
 
     def convert(self, code, stages=(1, 2), all_imports=False, from3=False,
-                reformat=True, run=True):
+                reformat=True, tobytes=True, run=True):
         """
         Converts the code block using ``futurize`` and returns the
         resulting code.
@@ -90,7 +90,7 @@ class CodeHandler(unittest.TestCase):
             code = self.reformat(code)
         self._write_test_script(code)
         self._futurize_test_script(stages=stages, all_imports=all_imports,
-                                   from3=from3)
+                                   from3=from3, tobytes=tobytes)
         output = self._read_test_script()
         if run:
             for interpreter in self.interpreters:
@@ -147,7 +147,7 @@ class CodeHandler(unittest.TestCase):
 
     def convert_check(self, before, expected, stages=(1, 2),
                       all_imports=False, ignore_imports=True, from3=False,
-                      run=True):
+                      tobytes=False, run=True):
         """
         Convenience method that calls convert() and check().
 
@@ -168,7 +168,7 @@ class CodeHandler(unittest.TestCase):
         """
         output = self.convert(before, stages=stages,
                               all_imports=all_imports, from3=from3,
-                              run=run)
+                              tobytes=tobytes, run=run)
         if all_imports:
             headers = self.headers2 if 2 in stages else self.headers1
         else:
@@ -247,13 +247,15 @@ class CodeHandler(unittest.TestCase):
         return newsource
 
     def _futurize_test_script(self, filename='mytestscript.py', stages=(1, 2),
-                              all_imports=False, from3=False):
+                              all_imports=False, from3=False, tobytes=False):
         params = []
         stages = list(stages)
         if all_imports:
             params.append('--all-imports')
         if from3:
             params.append('--from3')
+        if tobytes:
+            params.append('--tobytes')
         if stages == [1]:
             params.append('--stage1')
         elif stages == [2]:
