@@ -382,9 +382,9 @@ native_bytes = bytes
 def istext(obj):
     """
     Deprecated. Use::
-        isinstance(obj, str)
+        >>> isinstance(obj, str)
     after this import:
-        >>> from future.builtins import str, isinstance
+        >>> from future.builtins import str
     """
     return isinstance(obj, type(u''))
 
@@ -392,25 +392,42 @@ def istext(obj):
 def isbytes(obj):
     """
     Deprecated. Use::
-        isinstance(obj, bytes)
+        >>> isinstance(obj, bytes)
     after this import:
-        >>> from future.builtins import bytes, isinstance
+        >>> from future.builtins import bytes
     """
     return isinstance(obj, type(b''))
 
 
+def isnewbytes(obj):
+    """
+    Equivalent to the result of ``isinstance(obj, newbytes)`` were
+    ``__instancecheck__`` not overridden on the newbytes subclass. In
+    other words, it is REALLY a newbytes instance, not a Py2 native str
+    object?
+    """
+    # TODO: generalize this so that it works with subclasses of newbytes
+    # Import is here to avoid circular imports:
+    from future.builtins.backports.newbytes import newbytes
+    return type(obj) == newbytes
+
+
 def isint(obj):
     """
-    Tests whether an object is a Py3 ``int`` or either a Py2 ``int`` or
+    Deprecated. Tests whether an object is a Py3 ``int`` or either a Py2 ``int`` or
     ``long``.
 
-    Instead of using this function, you can use the following idiom:
-        isinstance(obj, numbers.Integral)
-    or simply:
-        isinstance(obj, int)
-    after this import:
-        from future.builtins import int, isinstance
+    Instead of using this function, you can use:
+
+        >>> from future.builtins import int
+        >>> isinstance(obj, int)
+
+    The following idiom is equivalent:
+
+        >>> from numbers import Integral
+        >>> isinstance(obj, Integral)
     """
+
     return isinstance(obj, numbers.Integral)
 
 
